

#include <stdio.h>
#include <stdlib.h>
#include "SDL.h"


SDL_Surface *loadBmp(const char *fichier)
{
	SDL_Surface *image;

	/* Chargement du bitmap "fichier" en memoire dans la surface image */
	image = SDL_LoadBMP(fichier);
	if ( image == NULL )
	{
		fprintf(stderr, "Echec de chargement du fichier %s : %s.\n", fichier, SDL_GetError());
		return NULL;
	}
	
	/* Verification du format de l'image */
	if ( (image->w != 160) || (image->h != 160) )
	if ( image == NULL )
	{
		fprintf(stderr, "L'image du fichier %s doit tre de taille 160*160 pixels.\n", fichier);
		SDL_FreeSurface(image);
		return NULL;
	}
	
	return image;
}


int main()
{

	SDL_Surface *ecran, *images[3];
	SDL_Event event;
	int image_courante = 0;

	atexit(SDL_Quit);
	
	/* initialisation de SDL_Video */
	if (SDL_Init(SDL_INIT_VIDEO) < 0)
	{
		fprintf(stderr, "Echec d'initialisation de SDL.\n");
		return 1;
	}
	printf("Bonjour le monde, SDL est initialis avec succs.\n");
	
	
	/* creation d'une fenetre avec une zone d'affichage de 160*160 pixels, une profondeur de bits egale  celle du serveur X ou de l'explorateur */
	ecran = SDL_SetVideoMode(160, 160, 0, SDL_ANYFORMAT);
	if ( ecran == NULL )
	{
		fprintf(stderr, "Echec de creation de la fenetre de 160*160 : %s.\n", SDL_GetError());
		return 1;
	}
	
	if ( !(images[0] = loadBmp("image1.bmp")) )
	{
		/* on libre SDL et on quitte */
		SDL_Quit();
		return 1;
	}
	
	if ( !(images[1] = loadBmp("image2.bmp")) )
	{
		/* on libre l'image dj charge */
		SDL_FreeSurface(images[0]);
		
		/* on libre SDL et on quitte */
		SDL_Quit();
		return 1;
	}

	if ( !(images[2] = loadBmp("image3.bmp")) )
	{
		/* on libre les images dj charges */
		SDL_FreeSurface(images[0]);
		SDL_FreeSurface(images[1]);
		
		/* on libre SDL et on quitte */
		SDL_Quit();
		return 1;
	}
	

	
	/* Copie de l'image  l'cran */
	SDL_BlitSurface(images[image_courante], NULL, ecran, NULL);
	
	/* Mise  jour de la zone d'affichage de la fenetre */
	SDL_UpdateRect(ecran, 0, 0, 0, 0);
	
	/* attente de l'appuis sur une touche pour quitter */
	while (SDL_WaitEvent(&event))
	{
		switch (event.type)
		{
		case SDL_KEYDOWN:
			switch (event.key.keysym.sym)
			{
			case SDLK_ESCAPE:
				/* On libre toutes les images charges */
				SDL_FreeSurface(images[0]);
				SDL_FreeSurface(images[1]);
				SDL_FreeSurface(images[2]);
			
				/* on libre SDL et on quitte */
				SDL_Quit();
				exit(0);
				break;
				
			case SDLK_SPACE:
				printf("Bienvenus dans l'espace.\n");
				break;
				
			case SDLK_DOWN:
				/* On change l'image  afficher */
				image_courante--;
				if (image_courante < 0)
					image_courante = 2;
				
				/* Copie de l'image  l'cran */
				SDL_BlitSurface(images[image_courante], NULL, ecran, NULL);
	
				/* Mise  jour de la zone d'affichage de la fenetre */
				SDL_UpdateRect(ecran, 0, 0, 0, 0);
				break;
				
			case SDLK_UP:
				/* On change l'image  afficher */
				image_courante++;
				if (image_courante > 2)
					image_courante = 0;
	
				/* Copie de l'image  l'cran */
				SDL_BlitSurface(images[image_courante], NULL, ecran, NULL);
	
				/* Mise  jour de la zone d'affichage de la fenetre */
				SDL_UpdateRect(ecran, 0, 0, 0, 0);
				break;
				
			default:
				printf("Une touche  t presse.\n");
			}
			break;
			
		case SDL_KEYUP:
			switch (event.key.keysym.sym)
			{
			case SDLK_SPACE:
			case SDLK_DOWN:
			case SDLK_UP:
				break;
				
			default:
				printf("Une touche  t relache\n");
			}
			break;
			
		case SDL_QUIT:
			/* On libre toutes les images charges */
			SDL_FreeSurface(images[0]);
			SDL_FreeSurface(images[1]);
			SDL_FreeSurface(images[2]);
			
			/* on libre SDL et on quitte */
			SDL_Quit();
			exit(0);
			break;
			
		default:
			;
		}
	}

	SDL_FreeSurface(images[0]);
	SDL_FreeSurface(images[1]);
	SDL_FreeSurface(images[2]);
	
	SDL_Quit();
	return 0;
}
